Py4JAuthenticationException (py4j-java 0.10.9.4 API)
Date: 2022-03-16

py4j

## Class Py4JAuthenticationException

- java.lang.Object
- - java.lang.Throwable
  - - java.lang.Exception
    - - java.lang.RuntimeException
      - - py4j.Py4JException
        - - py4j.Py4JAuthenticationException

- All Implemented Interfaces:
    java.io.Serializable

      public class Py4JAuthenticationException
      extends Py4JException

  See Also:
    Serialized Form

- - ### Constructor Summary

    Constructors
    Constructor and Description
    `Py4JAuthenticationException()`
    `Py4JAuthenticationException(java.lang.String message)`
    `Py4JAuthenticationException(java.lang.String message, java.lang.Throwable cause)`
    `Py4JAuthenticationException(java.lang.Throwable cause)`

  - ### Method Summary

    - ### Methods inherited from class java.lang.Throwable

      `addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString`

    - ### Methods inherited from class java.lang.Object

      `clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait`

- - ### Constructor Detail

    - #### Py4JAuthenticationException

          public Py4JAuthenticationException()

    - #### Py4JAuthenticationException

          public Py4JAuthenticationException(java.lang.String message)

    - #### Py4JAuthenticationException

          public Py4JAuthenticationException(java.lang.String message,
                                             java.lang.Throwable cause)

    - #### Py4JAuthenticationException

          public Py4JAuthenticationException(java.lang.Throwable cause)